@@ -396,5 +396,9 @@ class SpecialistPoolServiceGrpcTransport(SpecialistPoolServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("SpecialistPoolServiceGrpcTransport",)
